"""
Application-class that implements pyFoamCloneCase.py
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.RunDictionary.SolutionDirectory import SolutionDirectory

class CloneCase(PyFoamApplication):
    def __init__(self):
        description="""
Clones a case by copying the system, constant and 0-directories
"""
        PyFoamApplication.__init__(self,description=description,usage="%prog <source> <destination>",interspersed=True,nr=2)

    def addOptions(self):
        self.parser.add_option("--chemkin",
                         action="store_true",
                         dest="chemkin",
                         default=False,
                         help="Also copy the Chemkin-directory")
        self.parser.add_option("--add-item",
                         action="append",
                         dest="additional",
                         default=[],
                         help="Add a subdirectory to the list of cloned items (can be used more often than once)")

    def run(self):
        sName=self.parser.getArgs()[0]
        dName=self.parser.getArgs()[1]
        
        sol=SolutionDirectory(sName)

        if self.parser.getOptions().chemkin:
            sol.addToClone("chemkin")

        for a in self.parser.getOptions().additional:
            sol.addToClone(a)
            
        sol.cloneCase(dName)
